@@ -2135,6 +2135,35 @@ def test_dask_array(pyi_builder):
     """)
 
 
+# Basic test for dask's `distributed` package, based on quickstart example from their documentation.
+@importorskip('distributed')
+def test_dask_distributed(pyi_builder):
+    pyi_builder.test_source("""
+        import multiprocessing
+        from dask.distributed import Client
+
+        def process():
+            client = Client()
+
+            def square(x):
+                return x ** 2
+
+            def neg(x):
+                return -x
+
+            A = client.map(square, range(10))
+            B = client.map(neg, A)
+
+            total = client.submit(sum, B)
+            return total.result()
+
+        if __name__ == '__main__':
+            multiprocessing.freeze_support()
+            result = process()
+            assert result == -285
+    """)
+
+
 @importorskip('tables')
 def test_pytables(pyi_builder):
     # NOTE: run_from_path=True prevents `pyi_builder` from completely clearing the `PATH` environment variable. At the
@@ -2386,6 +2415,39 @@ def test_sv_ttk(pyi_builder):
     """)
 
 
+@importorskip('tkinterdnd2')
+def test_tkinterdnd2(pyi_builder):
+    if not _tkinter_fully_usable():
+        pytest.skip("tkinter is not fully usable.")
+    pyi_builder.test_source("""
+        import tkinter
+        import tkinterdnd2
+
+        root = tkinterdnd2.TkinterDnD.Tk()
+
+        list_box = tkinter.Listbox(root)
+        list_box.insert(1, "drag files here")
+
+        list_box.drop_target_register(tkinterdnd2.DND_FILES)
+        list_box.dnd_bind('<<Drop>>', lambda e: list_box.insert(tkinter.END, e.data))
+
+        list_box.pack()
+
+        def shutdown_timer_callback():
+            print("Shutting down!")
+            root.destroy()
+
+        shutdown_interval = 1000  # ms
+        print(f"Starting shutdown timer ({shutdown_interval} ms)...")
+        root.after(shutdown_interval, shutdown_timer_callback)
+
+        print("Entering main loop...")
+        root.mainloop()
+
+        print("Done!")
+    """)
+
+
 @importorskip('toga')
 def test_toga(pyi_builder):
     pyi_builder.test_script(
@@ -2429,12 +2491,17 @@ def test_fsspec_protocols(pyi_builder, tmp_path):
                 working_protocols.append(protocol)
             except ImportError:
                 pass
+            except Exception:
+                # Work around for fsspec/filesystem_spec#1805
+                pass
 
         return sorted(working_protocols)
 
     protocols_unfrozen = _get_working_fsspec_protocols()
     print(f"Unfrozen protocols: {protocols_unfrozen}")
 
+    assert protocols_unfrozen, "No working protocols found!"
+
     # Obtain list of working protocols in frozen application.
     output_file = tmp_path / "output.txt"
 
@@ -2449,6 +2516,9 @@ def test_fsspec_protocols(pyi_builder, tmp_path):
                 working_protocols.append(protocol)
             except ImportError:
                 pass
+            except Exception:
+                # Work-around for fsspec/filesystem_spec#1805
+                pass
 
         with open(sys.argv[1], 'w') as fp:
             for protocol in working_protocols:
@@ -2553,3 +2623,43 @@ def test_pypdfium2(pyi_builder):
     pyi_builder.test_source("""
         import pypdfium2
     """)
+
+
+@importorskip('dateutil')
+def test_dateutil(pyi_builder):
+    pyi_builder.test_source("""
+        from dateutil.zoneinfo import getzoneinfofile_stream
+
+        assert getzoneinfofile_stream()
+    """)
+
+
+@importorskip('niquests')
+def test_niquests(pyi_builder):
+    pyi_builder.test_source("""
+        import niquests
+
+        try:
+            with niquests.Session() as s:
+                s.get("http://tarpit/timeout", timeout=0.001)
+        except (niquests.ConnectionError, niquests.Timeout):
+            pass
+
+        try:
+            with niquests.Session(disable_http1=True) as s:
+                s.get("http://tarpit/timeout", timeout=0.001)
+        except (niquests.ConnectionError, niquests.Timeout):
+            pass
+
+        try:
+            with niquests.Session(disable_http1=True, disable_http2=True) as s:
+                s.get("https://tarpit/timeout", timeout=0.001)
+        except (niquests.ConnectionError, niquests.Timeout):
+            pass
+
+        try:
+            with niquests.Session() as s:
+                s.get("sse://tarpit/timeout", timeout=0.001)
+        except (niquests.ConnectionError, niquests.Timeout):
+            pass
+    """)
